#!/bin/bash

# This script is used to populate AMOS greylist
#
# @author David Mudrak <david@moodle.com>
#
# To use this script, get a vanilla Moodle source code in moodle/
# subdirectory and amos-all-stringids.txt generated by dump-stringids.php
# Be ware it takes several hours to populate the new greylist.txt

# dump of all strings generated by AMOS CLI dump-stringids.php
STRINGS=amos-all-stringids.txt

# the file to append greylisted strings into
GREYLIST=greylist.txt

# the file to append weirdlisted strings into
WEIRDLIST=weirdlist.txt

################################################################################

total=$(cat $STRINGS|wc -l)
let processed=0
let greylisted=0

while read string; do
	# extract the string identifer from the [stringid,component] format
	stringid=$(echo $string|sed 's/^\[\(.\+\),.*$/\1/')
	# search for stringid pattern in the moodle source code
	# stop searching after first two occurrences and return the number of occurrences
	# the string should be greylisted if it is found just once in the language pack
	# zero occurrance should be reviewed, too as they are not removed from AMOS repository
    	numoflines=$(grep -w -r -i $stringid moodle/* | head -n 2 | wc -l)
	if [ $numoflines -eq 1 ]; then
		(( greylisted++ ))
		echo $string >> $GREYLIST
	fi
	if [ $numoflines -eq 0 ]; then
		echo $string >> $WEIRDLIST
	fi
	(( processed++ ))

	if [ -n $processed ]; then
		ratio=$(echo $processed/$total*100|bc -l)
	else
		ratio=0
	fi

	echo -n -e "\rprocessed: $processed/$total " $(printf "%0.1f%%" $ratio) "greylisted: $greylisted"
done < $STRINGS
